/hg/icedtea: 8 new changesets
andrew at icedtea.classpath.org
andrew at icedtea.classpath.org
Fri Jul 23 01:27:07 PDT 2010
changeset 69e2cfc5643f in /hg/icedtea
details: http://icedtea.classpath.org/hg/icedtea?cmd=changeset;node=69e2cfc5643f
author: Andrew John Hughes <ahughes at redhat.com>
date: Fri Jul 23 09:11:11 2010 +0100
Add rebuild target to allow a quick OpenJDK rebuild (warning; may
not work in some cases due to flaws in OpenJDK's build system)
2010-07-08 Andrew John Hughes <ahughes at redhat.com>
* Makefile.am: (rebuild): Add new target to allow a
quick rebuild of OpenJDK in the manner of the existing
hotspot target.
changeset 2d3c4a7208ec in /hg/icedtea
details: http://icedtea.classpath.org/hg/icedtea?cmd=changeset;node=2d3c4a7208ec
author: Man Lung Wong <mwong at redhat.com>
date: Thu Jul 08 15:54:35 2010 -0400
Added encoding support for netx.
2010-07-08 Man Lung Wong <mwong at redhat.com>
* netx/net/sourceforge/jnlp/Parser.java: (getRootNode): Used
BufferedInputStream instead of InputStream to have mark and
reset method available. Passed the encoding to the
constructor of InputStreamReader, such that the stream will now
be parsed with the encoding the jnlp file is in. (getEncoding):
A new method which checks the first four bytes of input and
determines what the files encoding is.
changeset 77a59d9a4ce5 in /hg/icedtea
details: http://icedtea.classpath.org/hg/icedtea?cmd=changeset;node=77a59d9a4ce5
author: Jon VanAlten <jon.vanalten at redhat.com>
date: Mon Jul 12 11:13:35 2010 -0400
Eliminate spurious exception throwing in PulseAudio provider.
2010-07-12 Jon VanAlten <jon.vanalten at redhat.com>
* pulseaudio/src/java/org/classpath/icedtea/pulseaudio/PulseAudioDataL
ine.java
* pulseaudio/src/java/org/classpath/icedtea/pulseaudio/PulseAudioLine.
java
* pulseaudio/src/java/org/classpath/icedtea/pulseaudio/PulseAudioSourc
eDataLine.java
* pulseaudio/src/java/org/classpath/icedtea/pulseaudio/PulseAudioTarge
tDataLine.java: Eliminate spurious exception throwing from
open, close, read, write, drain, and flush calls on closed
lines. Use isOpen() API call instead of instance variable
where appropriate.
changeset b7ee63785b8d in /hg/icedtea
details: http://icedtea.classpath.org/hg/icedtea?cmd=changeset;node=b7ee63785b8d
author: Deepak Bhole <dbhole at redhat.com>
date: Fri Jul 23 09:16:18 2010 +0100
Use variadic macro for plugin debug message printing.
2010-06-14 Deepak Bhole <dbhole at redhat.com>
* plugin/icedteanp/IcedTeaJavaRequestProcessor.cc: Use
variadic macro for debug message printing.
* plugin/icedteanp/IcedTeaJavaRequestProcessor.h: Same.
* plugin/icedteanp/IcedTeaNPPlugin.cc: Same.
* plugin/icedteanp/IcedTeaPluginRequestProcessor.cc: Same.
* plugin/icedteanp/IcedTeaPluginUtils.cc: Same.
* plugin/icedteanp/IcedTeaPluginUtils.h: Same.
* plugin/icedteanp/IcedTeaScriptablePluginObject.cc: Same.
changeset 0bdf82fd01e8 in /hg/icedtea
details: http://icedtea.classpath.org/hg/icedtea?cmd=changeset;node=0bdf82fd01e8
author: Deepak Bhole <dbhole at redhat.com>
date: Tue Jul 13 14:48:45 2010 -0400
- Set timeout to 120 seconds (previous commit mistakenly changed it
to 10).
- Print debug info only in debug mode.
changeset 5ecc2d7f4f7c in /hg/icedtea
details: http://icedtea.classpath.org/hg/icedtea?cmd=changeset;node=5ecc2d7f4f7c
author: Deepak Bhole <dbhole at redhat.com>
date: Wed Jul 14 17:42:26 2010 -0400
Fix race conditions in plugin initialization code that were causing
hangs when loading multiple applets in parallel.
changeset 48c6bc3dbf4c in /hg/icedtea
details: http://icedtea.classpath.org/hg/icedtea?cmd=changeset;node=48c6bc3dbf4c
author: Xerxes R?nby <xerxes at zafena.se>
date: Mon Jul 19 14:39:53 2010 +0200
PR498: Catch-all handler can be unloaded.
2010-07-19 Gary Benson <gbenson at redhat.com> Xerxes
R?nby <xerxes at zafena.se>
PR icedtea/498
* ports/hotspot/src/share/vm/shark/sharkTopLevelBlock.cpp
(SharkTopLevelBlock::handle_exception): Catch-all handler can be
unloaded.
changeset 0b272cf7e4a3 in /hg/icedtea
details: http://icedtea.classpath.org/hg/icedtea?cmd=changeset;node=0b272cf7e4a3
author: Omair Majid <omajid at redhat.com>
date: Tue Jul 20 09:35:12 2010 -0400
netx: do not use Look and Feel related methods for setting up
security dialogs
2010-07-20 Omair Majid <omajid at redhat.com>
PR icedtea/372
* netx/net/sourceforge/jnlp/security/SecurityDialogUI.java: Renamed
to..
* netx/net/sourceforge/jnlp/security/SecurityDialogPanel.java: New
file. Remove all usage of Look and Feel related functionality.
Extend JPanel. (createSetValueListener): New method.
(setVisible): New method. (requestFocusOnDefaultButton): New
method.
* netx/net/sourceforge/jnlp/security/AccessWarningPane.java Extend
SecurityDialogPanel instead of SecurityDialogUI
(AccessWarningPane): Take a SecurityWarningDialog instead of a
JComponent as a paramenter. Call addComponents.
(installComponents): Renamed to (addComponents): New method.
(R): Moved to parent class. (htmlWrap): Likewise.
* netx/net/sourceforge/jnlp/security/AppletWarningPane.java Extend
SecurityDialogPanel instead of SecurityDialogUI
(AppletWarningPane): Take a SecurityWarningDialog instead of a
JComponent as a paramter. Call addComponents.
(installComponents): Renamed to... (addComponents): New method.
(htmlWrap): Moved to parent class.
* netx/net/sourceforge/jnlp/security/CertWarningPane.java Extend
SecurityDialogPanel instead of SecurityDialogUI
(CertWarningPane): Take a SecurityWarningDialog instead of a
JComponent as a parameter. Call addComponents.
(installComponents): Renamed to... (addComponents): New method.
(R): Moved to parent class. (htmlWrap): Likewise.
(CheckBoxListener): Add debug information.
* netx/net/sourceforge/jnlp/security/CertsInfoPane.java Extend
SecurityDialogPanel instead of SecurityDialogUI (CertsInfoPane):
Take a SecurityWarningDialog instead of a JComponent as a
parameter. Call addComponents. (installComponents): Renamed
to... (addComponents): New method.
* netx/net/sourceforge/jnlp/security/MoreInfoPane.java Extend
SecurityDialogPanel instead of SecurityDialogUI (MoreInfoPane):
Take a SecurityWarningDialog instead of a JComponent as a
parameter. Call addComponents. (installComponents): Renamed
to... (addComponents): New method. (R): Moved to parent
class. (htmlWrap): Likewise.
* netx/net/sourceforge/jnlp/security/SecurityWarningDialog.java
Extend JDialog instead of JOptionPane. Add panel, value as new
fields. (SecurityWarningDialog): Call super and initDialog.
(showAccessWarningDialog): Modified to use the cleaned-up api.
(showCertWarningDialog): Likewise. (showMoreInfoDialog):
Likewise. (showCertInfoDialog): Likewise.
(showSingleCertInfoDialog): Likewise. (showAppletWarning):
Likewise. (createDialog): Renamed to... (initDialog): New
method. Clean up api and remove JOptionPane references.
(updateUI): Renamed to... (installPanel): Switch from Look and
Feel related setUI methods to simple JComponents.
(selectDefaultButton): New method. Causes the default button to
request focus. (setValue): New method. Set the return value
of this dialog. (getValue): New method. Get the return value of
this dialog. (setSystemLookAndFeel): New method. Set the Look
and Feel to the System look and feel.
* netx/net/sourceforge/jnlp/security/SingleCertInfoPane.java
(SingleCertInfoPane): Take a SecurityWarningDialog instead of a
JComponent as a parameter. (buildTree): Use parant instead
of optionPane. (populateTable): Likewise.
* netx/net/sourceforge/jnlp/security/viewer/CertificatePane.java:
Extend JPanel instead of SecurityDialogUI. Add two new fields:
parent and defaultFocusComponent. (CertificatePane): Take a
JDialog as the argument. (installUI): Removed.
(setSystemLookAndFeel): Removed. (installComponents): Renamed to
... (addComponents): New method. (focusOnDefaultButton): New
method. Makes the defaultFocusComponent get focus.
(CloseButtonListener): New class. Disposes the JDialog.
* netx/net/sourceforge/jnlp/security/viewer/CertificateViewer.java:
Extend JDialog instead of JOptionPane (CertificateViewer):
Initialize the JDialog, add the CertificatePanel and set default
focus. (updateUI): Removed. (centerDialog): Takes no
arguments. (createDialog): Removed. (showCertificateViewer):
Use the new cleaned up api for CertificateViewer.
(setSystemLookAndFeel): New method. Sets the LookAndFeel of the
system.
diffstat:
27 files changed, 960 insertions(+), 904 deletions(-)
ChangeLog | 161 +++++++
Makefile.am | 15
netx/net/sourceforge/jnlp/Parser.java | 72 +++
netx/net/sourceforge/jnlp/security/AccessWarningPane.java | 47 --
netx/net/sourceforge/jnlp/security/AppletWarningPane.java | 27 -
netx/net/sourceforge/jnlp/security/CertWarningPane.java | 61 +-
netx/net/sourceforge/jnlp/security/CertsInfoPane.java | 19
netx/net/sourceforge/jnlp/security/MoreInfoPane.java | 39 -
netx/net/sourceforge/jnlp/security/SecurityDialogPanel.java | 129 ++++++
netx/net/sourceforge/jnlp/security/SecurityDialogUI.java | 204 ---------
netx/net/sourceforge/jnlp/security/SecurityWarningDialog.java | 187 ++++----
netx/net/sourceforge/jnlp/security/SingleCertInfoPane.java | 7
netx/net/sourceforge/jnlp/security/viewer/CertificatePane.java | 78 +--
netx/net/sourceforge/jnlp/security/viewer/CertificateViewer.java | 129 ++----
plugin/icedteanp/IcedTeaJavaRequestProcessor.cc | 16
plugin/icedteanp/IcedTeaNPPlugin.cc | 214 +++++-----
plugin/icedteanp/IcedTeaPluginRequestProcessor.cc | 46 +-
plugin/icedteanp/IcedTeaPluginUtils.cc | 102 ++--
plugin/icedteanp/IcedTeaPluginUtils.h | 66 ---
plugin/icedteanp/IcedTeaScriptablePluginObject.cc | 58 +-
plugin/icedteanp/java/sun/applet/PluginMessageConsumer.java | 23 -
plugin/icedteanp/java/sun/applet/PluginMessageHandlerWorker.java | 4
ports/hotspot/src/share/vm/shark/sharkTopLevelBlock.cpp | 6
pulseaudio/src/java/org/classpath/icedtea/pulseaudio/PulseAudioDataLine.java | 29 -
pulseaudio/src/java/org/classpath/icedtea/pulseaudio/PulseAudioLine.java | 6
pulseaudio/src/java/org/classpath/icedtea/pulseaudio/PulseAudioSourceDataLine.java | 36 -
pulseaudio/src/java/org/classpath/icedtea/pulseaudio/PulseAudioTargetDataLine.java | 83 ++-
diffs (truncated from 4005 to 500 lines):
diff -r b52dc7f36b70 -r 0b272cf7e4a3 ChangeLog
--- a/ChangeLog Fri Jul 23 00:26:40 2010 +0100
+++ b/ChangeLog Tue Jul 20 09:35:12 2010 -0400
@@ -1,3 +1,164 @@ 2010-07-08 Omair Majid <omajid at redhat.
+2010-07-19 Omair Majid <omajid at redhat.com>
+
+ PR icedtea/372
+ * netx/net/sourceforge/jnlp/security/SecurityDialogUI.java: Renamed to..
+ * netx/net/sourceforge/jnlp/security/SecurityDialogPanel.java: New file.
+ Remove all usage of Look and Feel related functionality. Extend JPanel.
+ (createSetValueListener): New method.
+ (setVisible): New method.
+ (requestFocusOnDefaultButton): New method.
+ * netx/net/sourceforge/jnlp/security/AccessWarningPane.java
+ Extend SecurityDialogPanel instead of SecurityDialogUI
+ (AccessWarningPane): Take a SecurityWarningDialog instead of a JComponent
+ as a paramenter. Call addComponents.
+ (installComponents): Renamed to
+ (addComponents): New method.
+ (R): Moved to parent class.
+ (htmlWrap): Likewise.
+ * netx/net/sourceforge/jnlp/security/AppletWarningPane.java
+ Extend SecurityDialogPanel instead of SecurityDialogUI
+ (AppletWarningPane): Take a SecurityWarningDialog instead of a JComponent
+ as a paramter. Call addComponents.
+ (installComponents): Renamed to...
+ (addComponents): New method.
+ (htmlWrap): Moved to parent class.
+ * netx/net/sourceforge/jnlp/security/CertWarningPane.java
+ Extend SecurityDialogPanel instead of SecurityDialogUI
+ (CertWarningPane): Take a SecurityWarningDialog instead of a JComponent as
+ a parameter. Call addComponents.
+ (installComponents): Renamed to...
+ (addComponents): New method.
+ (R): Moved to parent class.
+ (htmlWrap): Likewise.
+ (CheckBoxListener): Add debug information.
+ * netx/net/sourceforge/jnlp/security/CertsInfoPane.java
+ Extend SecurityDialogPanel instead of SecurityDialogUI
+ (CertsInfoPane): Take a SecurityWarningDialog instead of a JComponent as a
+ parameter. Call addComponents.
+ (installComponents): Renamed to...
+ (addComponents): New method.
+ * netx/net/sourceforge/jnlp/security/MoreInfoPane.java
+ Extend SecurityDialogPanel instead of SecurityDialogUI
+ (MoreInfoPane): Take a SecurityWarningDialog instead of a JComponent as a
+ parameter. Call addComponents.
+ (installComponents): Renamed to...
+ (addComponents): New method.
+ (R): Moved to parent class.
+ (htmlWrap): Likewise.
+ * netx/net/sourceforge/jnlp/security/SecurityWarningDialog.java
+ Extend JDialog instead of JOptionPane. Add panel, value as new fields.
+ (SecurityWarningDialog): Call super and initDialog.
+ (showAccessWarningDialog): Modified to use the cleaned-up api.
+ (showCertWarningDialog): Likewise.
+ (showMoreInfoDialog): Likewise.
+ (showCertInfoDialog): Likewise.
+ (showSingleCertInfoDialog): Likewise.
+ (showAppletWarning): Likewise.
+ (createDialog): Renamed to...
+ (initDialog): New method. Clean up api and remove JOptionPane references.
+ (updateUI): Renamed to...
+ (installPanel): Switch from Look and Feel related setUI methods to simple
+ JComponents.
+ (selectDefaultButton): New method. Causes the default button to request
+ focus.
+ (setValue): New method. Set the return value of this dialog.
+ (getValue): New method. Get the return value of this dialog.
+ (setSystemLookAndFeel): New method. Set the Look and Feel to the System
+ look and feel.
+ * netx/net/sourceforge/jnlp/security/SingleCertInfoPane.java
+ (SingleCertInfoPane): Take a SecurityWarningDialog instead of a JComponent
+ as a parameter.
+ (buildTree): Use parant instead of optionPane.
+ (populateTable): Likewise.
+ * netx/net/sourceforge/jnlp/security/viewer/CertificatePane.java: Extend
+ JPanel instead of SecurityDialogUI. Add two new fields: parent and
+ defaultFocusComponent.
+ (CertificatePane): Take a JDialog as the argument.
+ (installUI): Removed.
+ (setSystemLookAndFeel): Removed.
+ (installComponents): Renamed to ...
+ (addComponents): New method.
+ (focusOnDefaultButton): New method. Makes the defaultFocusComponent get
+ focus.
+ (CloseButtonListener): New class. Disposes the JDialog.
+ * netx/net/sourceforge/jnlp/security/viewer/CertificateViewer.java: Extend
+ JDialog instead of JOptionPane
+ (CertificateViewer): Initialize the JDialog, add the CertificatePanel and
+ set default focus.
+ (updateUI): Removed.
+ (centerDialog): Takes no arguments.
+ (createDialog): Removed.
+ (showCertificateViewer): Use the new cleaned up api for CertificateViewer.
+ (setSystemLookAndFeel): New method. Sets the LookAndFeel of the system.
+
+2010-07-19 Gary Benson <gbenson at redhat.com>
+ Xerxes RÃ¥nby <xerxes at zafena.se>
+
+ PR icedtea/498
+ * ports/hotspot/src/share/vm/shark/sharkTopLevelBlock.cpp
+ (SharkTopLevelBlock::handle_exception): Catch-all handler can be unloaded.
+
+2010-07-14 Deepak Bhole <dbhole at redhat.com>
+
+ * plugin/icedteanp/java/sun/applet/PluginMessageConsumer.java: Add a new
+ processedIds list to track which instances have been instantiated.
+ (okToProcess): Register width as priority only after handle is acquired.
+ Process resize messages only after tag and handle are processed.
+ (notifyWorkerIsFree): Add instance id to processedIds list if the worked
+ being free'd is an init worker.
+ (getFreeWorker): Create new normal worked only if worker count is less
+ than MAX_WORKERS - PRIORITY_WORKERS.
+ (dumpWorkerStatus): New method. Useful when debugging -- prints status of
+ all workers.
+ * plugin/icedteanp/java/sun/applet/PluginMessageHandlerWorker.java
+ (toString): New method. Returns the string representation of the worker
+ instance at call time.
+
+2010-07-13 Deepak Bhole <dbhole at redhat.com>
+
+ * plugin/icedteanp/IcedTeaJavaRequestProcessor.h: Set timeout to 120
+ seconds (previous commit mistakenly changed it to 10).
+ * plugin/icedteanp/IcedTeaPluginUtils.h: Print debug info only in debug
+ mode.
+
+2010-06-14 Deepak Bhole <dbhole at redhat.com>
+
+ * plugin/icedteanp/IcedTeaJavaRequestProcessor.cc: Use variadic macro
+ for debug message printing.
+ * plugin/icedteanp/IcedTeaJavaRequestProcessor.h: Same.
+ * plugin/icedteanp/IcedTeaNPPlugin.cc: Same.
+ * plugin/icedteanp/IcedTeaPluginRequestProcessor.cc: Same.
+ * plugin/icedteanp/IcedTeaPluginUtils.cc: Same.
+ * plugin/icedteanp/IcedTeaPluginUtils.h: Same.
+ * plugin/icedteanp/IcedTeaScriptablePluginObject.cc: Same.
+
+2010-07-12 Jon VanAlten <jon.vanalten at redhat.com>
+
+ * pulseaudio/src/java/org/classpath/icedtea/pulseaudio/PulseAudioDataLine.java
+ * pulseaudio/src/java/org/classpath/icedtea/pulseaudio/PulseAudioLine.java
+ * pulseaudio/src/java/org/classpath/icedtea/pulseaudio/PulseAudioSourceDataLine.java
+ * pulseaudio/src/java/org/classpath/icedtea/pulseaudio/PulseAudioTargetDataLine.java:
+ Eliminate spurious exception throwing from open, close, read, write,
+ drain, and flush calls on closed lines.
+ Use isOpen() API call instead of instance variable where appropriate.
+
+2010-07-08 Man Lung Wong <mwong at redhat.com>
+
+ * netx/net/sourceforge/jnlp/Parser.java:
+ (getRootNode): Used BufferedInputStream instead of InputStream to
+ have mark and reset method available. Passed the encoding to the
+ constructor of InputStreamReader, such that the stream will now
+ be parsed with the encoding the jnlp file is in.
+ (getEncoding): A new method which checks the first four bytes of input
+ and determines what the files encoding is.
+
+2010-07-08 Andrew John Hughes <ahughes at redhat.com>
+
+ * Makefile.am:
+ (rebuild): Add new target to allow a quick
+ rebuild of OpenJDK in the manner of the existing
+ hotspot target.
+
2010-07-08 Omair Majid <omajid at redhat.com>
* plugin/icedteanp/java/sun/applet/PluginAppletViewer.java:
diff -r b52dc7f36b70 -r 0b272cf7e4a3 Makefile.am
--- a/Makefile.am Fri Jul 23 00:26:40 2010 +0100
+++ b/Makefile.am Tue Jul 20 09:35:12 2010 -0400
@@ -1948,6 +1948,21 @@ stamps/icedtea-boot.stamp: stamps/bootst
mkdir -p stamps
touch $@
+# Rebuild targets
+
+rebuild:
+if BOOTSTRAPPING
+ rm -f stamps/icedtea-boot.stamp
+ rm -f stamps/icedtea-stage1.stamp
+ $(ARCH_PREFIX) $(MAKE) icedtea-stage1
+ @echo "bootstrap-poured IcedTea is served (again):" $(BOOT_BUILD_OUTPUT_DIR)/j2sdk-image
+else
+ rm -f stamps/icedtea.stamp
+ rm -f stamps/icedtea-stage2.stamp
+ $(ARCH_PREFIX) $(MAKE) icedtea-stage2
+ @echo "IcedTea is served (again):" $(BUILD_OUTPUT_DIR)/j2sdk-image
+endif
+
hotspot:
if BOOTSTRAPPING
rm -f stamps/icedtea-boot.stamp
diff -r b52dc7f36b70 -r 0b272cf7e4a3 netx/net/sourceforge/jnlp/Parser.java
--- a/netx/net/sourceforge/jnlp/Parser.java Fri Jul 23 00:26:40 2010 +0100
+++ b/netx/net/sourceforge/jnlp/Parser.java Tue Jul 20 09:35:12 2010 -0400
@@ -1168,12 +1168,16 @@ class Parser {
Node document = new Node(TinyParser.parseXML(input));
Node jnlpNode = getChildNode(document, "jnlp"); // skip comments
*/
+
+ //A BufferedInputStream is used to allow marking and reseting
+ //of a stream.
+ BufferedInputStream bs = new BufferedInputStream(input);
/* NANO */
final XMLElement xml = new XMLElement();
final PipedInputStream pin = new PipedInputStream();
- final PipedOutputStream pout = new PipedOutputStream(pin);
- final InputStreamReader isr = new InputStreamReader(input);
+ final PipedOutputStream pout = new PipedOutputStream(pin);
+ final InputStreamReader isr = new InputStreamReader(bs, getEncoding(bs));
// Clean the jnlp xml file of all comments before passing
// it to the parser.
new Thread(
@@ -1196,7 +1200,69 @@ class Parser {
throw new ParseException(R("PBadXML"), ex);
}
}
+
+ /**
+ * Returns the name of the encoding used in this InputStream.
+ *
+ * @param input the InputStream
+ * @return a String representation of encoding
+ */
+ private static String getEncoding(InputStream input) throws IOException{
+ //Fixme: This only recognizes UTF-8, UTF-16, and
+ //UTF-32, which is enough to parse the prolog portion of xml to
+ //find out the exact encoding (if it exists). The reason being
+ //there could be other encodings, such as ISO 8859 which is 8-bits
+ //but it supports latin characters.
+ //So what needs to be done is to parse the prolog and retrieve
+ //the exact encoding from it.
+ int[] s = new int[4];
+ String encoding = "UTF-8";
+
+ //Determine what the first four bytes are and store
+ //them into an int array.
+ input.mark(4);
+ for (int i = 0; i < 4; i++) {
+ s[i] = input.read();
+ }
+ input.reset();
+
+ //Set the encoding base on what the first four bytes of the
+ //inputstream turn out to be (following the information from
+ //www.w3.org/TR/REC-xml/#sec-guessing).
+ if (s[0] == 255) {
+ if (s[1] == 254) {
+ if (s[2] != 0 || s[3] != 0) {
+ encoding = "UnicodeLittle";
+ } else {
+ encoding = "X-UTF-32LE-BOM";
+ }
+ }
+ } else if (s[0] == 254 && s[1] == 255 && (s[2] != 0 ||
+ s[3] != 0)) {
+ encoding = "UTF-16";
+
+ } else if (s[0] == 0 && s[1] == 0 && s[2] == 254 &&
+ s[3] == 255) {
+ encoding = "X-UTF-32BE-BOM";
+
+ } else if (s[0] == 0 && s[1] == 0 && s[2] == 0 &&
+ s[3] == 60) {
+ encoding = "UTF-32BE";
+
+ } else if (s[0] == 60 && s[1] == 0 && s[2] == 0 &&
+ s[3] == 0) {
+ encoding = "UTF-32LE";
+
+ } else if (s[0] == 0 && s[1] == 60 && s[2] == 0 &&
+ s[3] == 63) {
+ encoding = "UTF-16BE";
+ } else if (s[0] == 60 && s[1] == 0 && s[2] == 63 &&
+ s[3] == 0) {
+ encoding = "UTF-16LE";
+ }
+
+ return encoding;
+ }
}
-
diff -r b52dc7f36b70 -r 0b272cf7e4a3 netx/net/sourceforge/jnlp/security/AccessWarningPane.java
--- a/netx/net/sourceforge/jnlp/security/AccessWarningPane.java Fri Jul 23 00:26:40 2010 +0100
+++ b/netx/net/sourceforge/jnlp/security/AccessWarningPane.java Tue Jul 20 09:35:12 2010 -0400
@@ -51,44 +51,42 @@ import javax.swing.ImageIcon;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JCheckBox;
-import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SwingConstants;
import net.sourceforge.jnlp.JNLPFile;
-import net.sourceforge.jnlp.runtime.JNLPRuntime;
/**
- * Provides the look and feel for a SecurityWarningDialog. These dialogs are
+ * Provides a panel to show inside a SecurityWarningDialog. These dialogs are
* used to warn the user when either signed code (with or without signing
* issues) is going to be run, or when service permission (file, clipboard,
* printer, etc) is needed with unsigned code.
*
* @author <a href="mailto:jsumali at redhat.com">Joshua Sumali</a>
*/
-public class AccessWarningPane extends SecurityDialogUI {
+public class AccessWarningPane extends SecurityDialogPanel {
JCheckBox alwaysAllow;
Object[] extras;
- public AccessWarningPane(JComponent x, CertVerifier certVerifier) {
+ public AccessWarningPane(SecurityWarningDialog x, CertVerifier certVerifier) {
super(x, certVerifier);
+ addComponents();
}
- public AccessWarningPane(JComponent x, Object[] extras, CertVerifier certVerifier) {
+ public AccessWarningPane(SecurityWarningDialog x, Object[] extras, CertVerifier certVerifier) {
super(x, certVerifier);
this.extras = extras;
+ addComponents();
}
/**
- * Creates the actual GUI components, and adds it to <code>optionPane</code>
+ * Creates the actual GUI components, and adds it to this panel
*/
- protected void installComponents() {
- SecurityWarningDialog.AccessType type =
- ((SecurityWarningDialog)optionPane).getType();
- JNLPFile file =
- ((SecurityWarningDialog)optionPane).getFile();
+ private void addComponents() {
+ SecurityWarningDialog.AccessType type = parent.getType();
+ JNLPFile file = parent.getFile();
String name = "";
String publisher = "";
@@ -173,35 +171,22 @@ public class AccessWarningPane extends S
JButton run = new JButton("Allow");
JButton cancel = new JButton("Cancel");
- run.addActionListener(createButtonActionListener(0));
+ run.addActionListener(createSetValueListener(parent,0));
run.addActionListener(new CheckBoxListener());
- cancel.addActionListener(createButtonActionListener(1));
+ cancel.addActionListener(createSetValueListener(parent, 1));
initialFocusComponent = cancel;
buttonPanel.add(run);
buttonPanel.add(cancel);
buttonPanel.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));
//all of the above
- JPanel main = new JPanel();
- main.setLayout(new BoxLayout(main, BoxLayout.Y_AXIS));
- main.add(topPanel);
- main.add(infoPanel);
- main.add(buttonPanel);
+ setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));
+ add(topPanel);
+ add(infoPanel);
+ add(buttonPanel);
- optionPane.add(main, BorderLayout.CENTER);
}
- private static String R(String key) {
- return JNLPRuntime.getMessage(key);
- }
-
- private static String R(String key, Object param) {
- return JNLPRuntime.getMessage(key, new Object[] {param});
- }
-
- protected String htmlWrap (String s) {
- return "<html>"+s+"</html>";
- }
private class CheckBoxListener implements ActionListener {
public void actionPerformed(ActionEvent e) {
diff -r b52dc7f36b70 -r 0b272cf7e4a3 netx/net/sourceforge/jnlp/security/AppletWarningPane.java
--- a/netx/net/sourceforge/jnlp/security/AppletWarningPane.java Fri Jul 23 00:26:40 2010 +0100
+++ b/netx/net/sourceforge/jnlp/security/AppletWarningPane.java Tue Jul 20 09:35:12 2010 -0400
@@ -46,18 +46,18 @@ import javax.swing.BorderFactory;
import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JButton;
-import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
-public class AppletWarningPane extends SecurityDialogUI {
+public class AppletWarningPane extends SecurityDialogPanel {
- public AppletWarningPane(JComponent x, CertVerifier certVerifier) {
+ public AppletWarningPane(SecurityWarningDialog x, CertVerifier certVerifier) {
super(x, certVerifier);
+ addComponents();
}
- protected void installComponents() {
+ protected void addComponents() {
//Top label
String topLabelText = "While support for verifying signed code" +
@@ -95,9 +95,9 @@ public class AppletWarningPane extends S
yes.setPreferredSize(d);
no.setPreferredSize(d);
cancel.setPreferredSize(d);
- yes.addActionListener(createButtonActionListener(0));
- no.addActionListener(createButtonActionListener(1));
- cancel.addActionListener(createButtonActionListener(2));
+ yes.addActionListener(createSetValueListener(parent, 0));
+ no.addActionListener(createSetValueListener(parent, 1));
+ cancel.addActionListener(createSetValueListener(parent, 2));
initialFocusComponent = cancel;
buttonPanel.add(yes);
buttonPanel.add(no);
@@ -105,17 +105,12 @@ public class AppletWarningPane extends S
buttonPanel.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));
//all of the above
- JPanel main = new JPanel();
- main.setLayout(new BoxLayout(main, BoxLayout.Y_AXIS));
- main.add(topPanel);
- main.add(infoPanel);
- main.add(buttonPanel);
+ setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));
+ add(topPanel);
+ add(infoPanel);
+ add(buttonPanel);
- optionPane.add(main, BorderLayout.CENTER);
}
- protected String htmlWrap (String s) {
- return "<html>"+s+"</html>";
- }
}
diff -r b52dc7f36b70 -r 0b272cf7e4a3 netx/net/sourceforge/jnlp/security/CertWarningPane.java
--- a/netx/net/sourceforge/jnlp/security/CertWarningPane.java Fri Jul 23 00:26:40 2010 +0100
+++ b/netx/net/sourceforge/jnlp/security/CertWarningPane.java Tue Jul 20 09:35:12 2010 -0400
@@ -53,7 +53,6 @@ import javax.swing.ImageIcon;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JCheckBox;
-import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SwingConstants;
@@ -64,33 +63,31 @@ import net.sourceforge.jnlp.tools.KeyToo
import net.sourceforge.jnlp.tools.KeyTool;
/**
* Provides the look and feel for a SecurityWarningDialog. These dialogs are
* used to warn the user when either signed code (with or without signing
* issues) is going to be run, or when service permission (file, clipboard,
* printer, etc) is needed with unsigned code.
*
* @author <a href="mailto:jsumali at redhat.com">Joshua Sumali</a>
*/
-public class CertWarningPane extends SecurityDialogUI {
+public class CertWarningPane extends SecurityDialogPanel {
JCheckBox alwaysTrust;
CertVerifier certVerifier;
- public CertWarningPane(JComponent x, CertVerifier certVerifier) {
+ public CertWarningPane(SecurityWarningDialog x, CertVerifier certVerifier) {
super(x, certVerifier);
this.certVerifier = certVerifier;
+ addComponents();
}
/**
* Creates the actual GUI components, and adds it to <code>optionPane</code>
*/
- protected void installComponents() {
- SecurityWarningDialog.AccessType type =
- ((SecurityWarningDialog)optionPane).getType();
- JNLPFile file =
- ((SecurityWarningDialog)optionPane).getFile();
- Certificate c = ((SecurityWarningDialog)optionPane)
- .getJarSigner().getPublisher();
+ private void addComponents() {
+ SecurityWarningDialog.AccessType type = parent.getType();
+ JNLPFile file = parent.getFile();
+ Certificate c = parent.getJarSigner().getPublisher();
String name = "";
More information about the distro-pkg-dev
mailing list
@@ -64,33 +63,31 @@ import net.sourceforge.jnlp.tools.KeyToo
import net.sourceforge.jnlp.tools.KeyTool;
/**
- * Provides the look and feel for a SecurityWarningDialog. These dialogs are
+ * Provides the panel for using inside a SecurityWarningDialog. These dialogs are
* used to warn the user when either signed code (with or without signing
* issues) is going to be run, or when service permission (file, clipboard,
@@ -64,33 +63,31 @@ import net.sourceforge.jnlp.tools.KeyToo
}
/**
- * Creates the actual GUI components, and adds it to <code>optionPane</code>
+ * Creates the actual GUI components, and adds it to this panel
*/